@@ -11,7 +11,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.045'; # VERSION
+our $VERSION = '0.046'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -121,17 +121,11 @@ sub execute {
         $format = $self->format;
     }
 
-    # HACK: The 'stack' table should also be prefetched here (not
-    # joined).  But in DBIx-Class 0.08198, the prefetch feature seems
-    # to be broken.  See RT #78456 for details.  In the meantime, this
-    # seems to work around the problem, although it requires an extra
-    # trip to the database if we need the stack name in the listing.
     my $attrs = { order_by => [ qw(me.package_name me.package_version me.distribution_path) ],
-                  prefetch => {package => 'distribution'},
-                  join     => 'stack' };
+                  prefetch => ['stack', {package => 'distribution'}] };
 
     my $rs = $self->repos->db->select_registrations($where, $attrs);
-    $DB::single = 1;
+
     while( my $registration = $rs->next ) {
         print { $self->out } $registration->to_string($format);
     }
@@ -159,7 +153,7 @@ Pinto::Action::List - List the contents of a stack
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 AUTHOR
 
