@@ -21,7 +21,7 @@ use Pinto::Types qw(Uri Dir);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.045'; # VERSION
+our $VERSION = '0.046'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -34,6 +34,7 @@ has pinto_args => (
    default    => sub { {} },
    traits     => ['Hash'],
    handles    => { pinto_args => 'elements' },
+   lazy       => 1,
 );
 
 
@@ -42,6 +43,7 @@ has init_args => (
    default    => sub { {} },
    traits     => ['Hash'],
    handles    => { init_args => 'elements' },
+   lazy       => 1,
 );
 
 
@@ -73,9 +75,16 @@ has tb => (
    is       => 'ro',
    isa      => 'Test::Builder',
    init_arg => undef,
-   default  => => sub { __PACKAGE__->builder() },
+   default  => sub { __PACKAGE__->builder() },
 );
 
+#------------------------------------------------------------------------------
+# This force the repository to be constructed immediately.  Just
+# making the 'pinto' attribute non-lazy didn't work, probably due to
+# dependencies on other attributes.
+
+sub BUILD { $_[0]->pinto }
+
 #------------------------------------------------------------------------------
 
 sub _build_pinto {
@@ -368,7 +377,7 @@ Pinto::Tester - A class for testing a Pinto repository
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 AUTHOR
 
